@@ -122,11 +122,10 @@ class Bucket(core.Construct):
         self.bucket = None
 
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Create conditions
-        bucket_name_was_provided = bucket_name.strip()
-
-        bucket_already_exist = check_if_bucket_exist(
-            s3_bucket_name=bucket_name
-        )
+        # bucket_name_was_provided = bucket_name.strip()
+        # bucket_already_exist = check_if_bucket_exist(
+        #     s3_bucket_name=bucket_name
+        # )
 
         # Check if bucket has to be public
         public_read_access = (
@@ -146,91 +145,88 @@ class Bucket(core.Construct):
 
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Conditionally create resources
 
-        # S3 Bucket for S3
-        if bucket_name_was_provided and not bucket_already_exist:
+        # Only retain production bucket, with public assets
+        removal_policy = core.RemovalPolicy.DESTROY
+        if is_production and public_read_access:
+            removal_policy = core.RemovalPolicy.RETAIN
 
-            # Only retain production bucket, with public assets
-            removal_policy = core.RemovalPolicy.DESTROY
-            if is_production and public_read_access:
-                removal_policy = core.RemovalPolicy.RETAIN
+        # Default access level: PRIVATE
+        self.bucket = self.create_bucket(
+            logic_id="S3",
+            app_name=app_name,
+            bucket_name=bucket_name,
+            website_index_document=bucket_website_index_document,
+            website_error_document=bucket_website_error_document,
+            removal_policy=removal_policy,
+            access_control=_s3.BucketAccessControl.PRIVATE if not public_read_access else None,
+            block_public_access=_s3.BlockPublicAccess.BLOCK_ALL if not public_read_access else None,  # https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html
+        )
 
-            # Default access level: PRIVATE
-            self.bucket = self.create_bucket(
-                logic_id="S3",
-                app_name=app_name,
-                bucket_name=bucket_name,
-                website_index_document=bucket_website_index_document,
-                website_error_document=bucket_website_error_document,
-                removal_policy=removal_policy,
-                access_control=_s3.BucketAccessControl.PRIVATE if not public_read_access else None,
-                block_public_access=_s3.BlockPublicAccess.BLOCK_ALL if not public_read_access else None,  # https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html
+        if public_read_access:
+            # Grant access to anyone
+            self.bucket.grant_public_access()
+
+            self.bucket.add_cors_rule(
+                allowed_methods=[
+                    _s3.HttpMethods.GET,
+                    _s3.HttpMethods.POST,
+                    _s3.HttpMethods.PUT,
+                    _s3.HttpMethods.DELETE,
+                    _s3.HttpMethods.HEAD,
+                ],
+                allowed_origins=["*"],
+                allowed_headers=["*"],
             )
 
-            if public_read_access:
-                # Grant access to anyone
-                self.bucket.grant_public_access()
+        # Limit access to CDN
+        if bucket_has_cdn:
 
-                self.bucket.add_cors_rule(
-                    allowed_methods=[
-                        _s3.HttpMethods.GET,
-                        _s3.HttpMethods.POST,
-                        _s3.HttpMethods.PUT,
-                        _s3.HttpMethods.DELETE,
-                        _s3.HttpMethods.HEAD,
+            # Cloudflare doc https://support.cloudflare.com/hc/en-us/articles/360037983412-Configuring-an-Amazon-Web-Services-static-site-to-use-Cloudflare
+            cloudflare_ips = [
+                "2400:cb00::/32",
+                "2405:8100::/32",
+                "2405:b500::/32",
+                "2606:4700::/32",
+                "2803:f800::/32",
+                "2c0f:f248::/32",
+                "2a06:98c0::/29",
+                "103.21.244.0/22",
+                "103.22.200.0/22",
+                "103.31.4.0/22",
+                "104.16.0.0/12",
+                "108.162.192.0/18",
+                "131.0.72.0/22",
+                "141.101.64.0/18",
+                "162.158.0.0/15",
+                "172.64.0.0/13",
+                "173.245.48.0/20",
+                "188.114.96.0/20",
+                "190.93.240.0/20",
+                "197.234.240.0/22",
+                "198.41.128.0/17",
+            ]
+
+            self.bucket.add_to_resource_policy(
+                _iam.PolicyStatement(
+                    effect=_iam.Effect.DENY,
+                    principals=[_iam.Anyone()],
+                    actions=["s3:GetObject"],
+                    resources=[
+                        "arn:aws:s3:::" + bucket_name,
+                        "arn:aws:s3:::" + bucket_name + "/*",
                     ],
-                    allowed_origins=["*"],
-                    allowed_headers=["*"],
+                    conditions={"NotIpAddress": {"aws:SourceIp": cloudflare_ips}},
                 )
+            )
 
-            # Limit access to CDN
-            if bucket_has_cdn:
-
-                # Cloudflare doc https://support.cloudflare.com/hc/en-us/articles/360037983412-Configuring-an-Amazon-Web-Services-static-site-to-use-Cloudflare
-                cloudflare_ips = [
-                    "2400:cb00::/32",
-                    "2405:8100::/32",
-                    "2405:b500::/32",
-                    "2606:4700::/32",
-                    "2803:f800::/32",
-                    "2c0f:f248::/32",
-                    "2a06:98c0::/29",
-                    "103.21.244.0/22",
-                    "103.22.200.0/22",
-                    "103.31.4.0/22",
-                    "104.16.0.0/12",
-                    "108.162.192.0/18",
-                    "131.0.72.0/22",
-                    "141.101.64.0/18",
-                    "162.158.0.0/15",
-                    "172.64.0.0/13",
-                    "173.245.48.0/20",
-                    "188.114.96.0/20",
-                    "190.93.240.0/20",
-                    "197.234.240.0/22",
-                    "198.41.128.0/17",
-                ]
-
-                self.bucket.add_to_resource_policy(
-                    _iam.PolicyStatement(
-                        effect=_iam.Effect.DENY,
-                        principals=[_iam.Anyone()],
-                        actions=["s3:GetObject"],
-                        resources=[
-                            "arn:aws:s3:::" + bucket_name,
-                            "arn:aws:s3:::" + bucket_name + "/*",
-                        ],
-                        conditions={"NotIpAddress": {"aws:SourceIp": cloudflare_ips}},
-                    )
-                )
-
-                self.bucket.add_cors_rule(
-                    allowed_methods=[
-                        _s3.HttpMethods.GET,
-                        _s3.HttpMethods.POST,
-                        _s3.HttpMethods.PUT,
-                        _s3.HttpMethods.DELETE,
-                        _s3.HttpMethods.HEAD,
-                    ],
-                    allowed_origins=["*"],
-                    allowed_headers=["*"],
-                )
+            self.bucket.add_cors_rule(
+                allowed_methods=[
+                    _s3.HttpMethods.GET,
+                    _s3.HttpMethods.POST,
+                    _s3.HttpMethods.PUT,
+                    _s3.HttpMethods.DELETE,
+                    _s3.HttpMethods.HEAD,
+                ],
+                allowed_origins=["*"],
+                allowed_headers=["*"],
+            )
