@@ -1023,8 +1023,7 @@ class Microservice(core.Construct):
             rolling_update_configuration=_asg.RollingUpdateConfiguration(
                 max_batch_size=1,
                 min_instances_in_service=2 if is_ha else 1,
-                # min_successful_instances_percent=None,
-                # pause_time=None,
+                min_successful_instances_percent=100,
                 # ASG best practice https://aws.amazon.com/premiumsupport/knowledge-center/auto-scaling-group-rolling-updates/
                 suspend_processes=[
                     _asg.ScalingProcess.HEALTH_CHECK,
