@@ -1,11 +1,13 @@
 from aws_cdk import core, aws_iam as _iam
-
+from aws_cdk.core import Tags
 
 class ServiceUserForIAC(core.Construct):
     """Construct to create the Service User to deploy a stack from a CD/CI pipeline
 
     Args:
-        app_name (str): The application name. This will be used to generate the 'ApplicationName' tag for CSI compliancy. The ID of the application. This must be unique for each system, as it will be used to calculate the AWS costs of the systen
+        id (str): the logical id of the newly created resource
+        
+        app_name (str): The application name. This will be used to generate the 'ApplicationName' tag for CSI compliancy. The ID of the application. This must be unique for each system, as it will be used to calculate the AWS costs of the system
 
         environment (str): Specify the environment in which you want to deploy you system. Allowed values: Development, QA, Production, SharedServices 
 
@@ -30,14 +32,18 @@ class ServiceUserForIAC(core.Construct):
         scope: core.Construct,
         id: str,
         app_name,
-        environments_parameters,
         environment,
+        environments_parameters,
         s3_code_bucket_name=None,
         s3_assets_bucket_name=None,
         **kwargs
     ) -> None:
         super().__init__(scope, id, **kwargs)
 
+        # Apply mandatory tags
+        Tags.of(self).add("ApplicationName", app_name.lower().strip())
+        Tags.of(self).add("Environment", environment)
+
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Create conditions
 
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Validate input params
@@ -66,10 +72,11 @@ class ServiceUserForIAC(core.Construct):
 
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Create AWS resources
 
-        managed_policy = _iam.ManagedPolicy(
+        # Manage policy for IAC deployment
+        managed_policy_for_iac = _iam.ManagedPolicy(
             self,
             "managed_policy",
-            description=app_name + " managed policy for CDK",
+            description=app_name + " managed policy for IAC",
             statements=[
                 # Resource ALL
                 _iam.PolicyStatement(
@@ -252,15 +259,93 @@ class ServiceUserForIAC(core.Construct):
                         + account_id
                         + ":parameter/"
                         + app_name
+                        + "*",
+                        "arn:aws:ssm:eu-west-1:"
+                        + account_id
+                        + ":parameter/"
+                        + "common/"
                         + "*"
                     ],
                 ),
             ],
         )
 
+        # Managed policy for Configuration deployement
+        managed_policy_for_static_assets =  _iam.ManagedPolicy(
+                self,
+                "service_user_policies",
+                statements=[
+                    # S3 Configuration bucket permissions
+                    _iam.PolicyStatement(
+                        actions=["s3:*"],
+                        resources=[
+                            "arn:aws:s3:::"
+                            + aws_account["s3_config_bucket"]
+                            + "/"
+                            + app_name
+                            + "/"
+                            + environment
+                            + "/",
+                            "arn:aws:s3:::"
+                            + aws_account["s3_config_bucket"]
+                            + "/"
+                            + app_name
+                            + "/"
+                            + environment
+                            + "/*",
+                        ],
+                    ),
+                    _iam.PolicyStatement(
+                        actions=["s3:ListBucket*"],
+                        resources=["arn:aws:s3:::" + aws_account["s3_config_bucket"]],
+                    ),
+                ],
+            )
+        
+                # S3 Code bucket permissions
+        if s3_code_bucket_name:
+            service_user.add_managed_policy(
+                _iam.ManagedPolicy(
+                    self,
+                    "service_user_s3_code_bucket_policies",
+                    statements=[
+                        # S3 Assets bucket permissions
+                        _iam.PolicyStatement(
+                            actions=["s3:*"],
+                            resources=[
+                                "arn:aws:s3:::" + s3_code_bucket_name,
+                                "arn:aws:s3:::" + s3_code_bucket_name + "/*",
+                            ],
+                        ),
+                    ],
+                )
+            )
+
+            # S3 Assets bucket permissions
+        if s3_assets_bucket_name:
+            service_user.add_managed_policy(
+                _iam.ManagedPolicy(
+                    self,
+                    "service_user_s3_assets_bucket_policies",
+                    statements=[
+                        _iam.PolicyStatement(
+                            actions=["s3:*"],
+                            resources=[
+                                "arn:aws:s3:::" + s3_assets_bucket_name,
+                                "arn:aws:s3:::" + s3_assets_bucket_name + "/*",
+                            ],
+                        ),
+                    ],
+                )
+            )
+
+        # Service user
         self._service_user = _iam.User(
             self,
             "service_user",
-            managed_policies=[managed_policy],
-            user_name="SRVUSR-" + app_name + "_" + environment + "_cdk",
+            managed_policies=[
+                managed_policy_for_iac,
+                managed_policy_for_static_assets,
+                ],
+            user_name="SRVUSR-" + app_name + "_" + environment + "_iac",
         )
